"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { sendMessage } from "~/server/functions";

type sendMessageRequest = {
  senderId: number;
  receiverId: number;
  content: string;
  mediaUrl?: string;
  mediaType?: "text" | "image" | "video" | "audio" | "file" | "link";
};

export const POST = async (request: NextRequest) => {
  try {
    const url = new URL(request.url);
    const apiKey = url.searchParams.get("apiKey");
    if (apiKey !== process.env.API_KEY) {
      console.log("Invalid API Key");
      return NextResponse.json({ message: "Invalid API Key" }, { status: 401 });
    } 
    const body = await request.json() as sendMessageRequest;
    const {
      senderId,
      receiverId,
      content,
      mediaUrl = "",
      mediaType = "text",
    } = body;
    if (!senderId || !receiverId || !content) {
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });
    }
    const message = await sendMessage(senderId, receiverId, content, mediaUrl, mediaType);
    return NextResponse.json(message, { status: 201 });
  } catch (error) {
    console.error(error);
    return NextResponse.json({ message: "Error" }, { status: 500 });
  }
};
