"use server";
import { NextResponse } from "next/server";
import { createRelationshipRequest } from "~/server/functions";

interface CreateRequestRequest {
  apiKey: string;
  userId: number;
  targetUserId: number;
}

export async function POST(request: Request) {
  try {
    const { apiKey, userId, targetUserId } = await request.json() as CreateRequestRequest;
    console.log("Received request:", { apiKey, userId, targetUserId });

    if (apiKey !== process.env.API_KEY) {
      console.log("Invalid API Key");
      return NextResponse.json({ message: "Invalid API Key" }, { status: 401 });
    }

    if (!userId || !targetUserId) {
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });
    }

    console.log("Creating relationship request for user:", userId);
    const result = await createRelationshipRequest(userId, targetUserId);

    if (result) {
      console.log("Relationship request created successfully");
      return NextResponse.json({ result }, { status: 200 });
    } else {
      throw new Error("Failed to create relationship request");
    }
  } catch (error) {
    console.error("Error in createRequest:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error creating relationship request" }, { status: 500 });
  }
}
