"use server";
import { NextResponse } from "next/server";
import { deleteRelationship } from "~/server/functions";

interface DeleteRelationshipRequest {
  apiKey: string;
  relationshipId: number;
}

export async function POST(request: Request) {
  try {
    const { apiKey, relationshipId } = await request.json() as DeleteRelationshipRequest;
    console.log("Received request:", { apiKey, relationshipId });

    if (apiKey !== process.env.API_KEY) {
      console.log("Invalid API Key");
      return NextResponse.json({ message: "Invalid API Key" }, { status: 401 });
    }

    if (!relationshipId) {
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });
    }

    console.log("Deleting relationship:", relationshipId);
    const result = await deleteRelationship(relationshipId);

    if (result.success) {
      console.log("Relationship deleted successfully");
      return NextResponse.json({ result }, { status: 200 });
    } else {
      throw new Error("Failed to delete relationship");
    }
  } catch (error) {
    console.error("Error in deleteRelationship:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error deleting relationship" }, { status: 500 });
  }
}
