"use server";
import { NextResponse } from "next/server";
import { updateRelationshipRequest } from "~/server/functions";

interface UpdateRequestRequest {
  apiKey: string;
  relationshipId: number;
  status: 'accepted' | 'rejected';
}

export async function POST(request: Request) {
  try {
    const { apiKey, relationshipId, status } = await request.json() as UpdateRequestRequest;
    console.log("Received request:", { apiKey, relationshipId, status });

    if (apiKey !== process.env.API_KEY) {
      console.log("Invalid API Key");
      return NextResponse.json({ message: "Invalid API Key" }, { status: 401 });
    }

    if (!relationshipId || !status) {
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });
    }

    console.log("Updating relationship request:", relationshipId);
    const result = await updateRelationshipRequest(relationshipId, status);

    if (result.success) {
      console.log("Relationship request updated successfully");
      return NextResponse.json({ result }, { status: 200 });
    } else {
      throw new Error("Failed to update relationship request");
    }
  } catch (error) {
    console.error("Error in updateRequest:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error updating relationship request" }, { status: 500 });
  }
}
