import { NextResponse } from 'next/server';
import { updateUserPushToken } from '~/server/functions';

type Data = {
  apiKey: string;
  userId: string;
  pushToken: string;
};

export const POST = async (request: Request) => {
  try {
    const { apiKey, userId, pushToken } = await request.json() as Data;
    console.log('Received request:', { apiKey, userId, pushToken });

    if (apiKey !== process.env.API_KEY) {
      console.log('Invalid API Key');
      return NextResponse.json({ message: "Invalid API Key" }, { status: 401 });
    }

    console.log('Updating push token for user:', userId);
    await updateUserPushToken(parseInt(userId), pushToken);

    console.log('Push token updated successfully');
    return NextResponse.json({ message: "Push token updated successfully" });
  } catch (error) {
    console.error('Error in updatePushToken:', error);
    return NextResponse.json({ message: "Error updating push token" }, { status: 500 });
  }
};
