"use server";
import { NextResponse } from "next/server";
import { userLogin } from "~/server/functions";

interface LoginRequest {
  apiKey: string;
  username: string;
  password: string;
}

export async function POST(request: Request) {
  try {
    const { apiKey, username, password } = await request.json() as LoginRequest;
    console.log("Received request:", { apiKey, username, password });

    if (apiKey !== process.env.API_KEY) {
      console.log("Invalid API Key");
      return NextResponse.json({ message: "Invalid API Key" }, { status: 401 });
    }

    if (!username || !password) {
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });
    }

    console.log("Logging in user:", username);
    const result = await userLogin(username, password);

    if (result) {
      console.log("User logged in successfully");
      return NextResponse.json({ result }, { status: 200 });
    } else {
      throw new Error("Failed to log in user");
    }
  } catch (error) {
    console.error("Error in login:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error logging in user" }, { status: 500 });
  }
}
