"use server";
import { NextResponse } from "next/server";
import { updateUserPushToken } from "~/server/functions";

interface UpdatePushTokenRequest {
  apiKey: string;
  userId: number;
  pushToken: string;
}

export async function POST(request: Request) {
  try {
    const { apiKey, userId, pushToken } = await request.json() as UpdatePushTokenRequest;
    console.log("Received request:", { apiKey, userId, pushToken });
    if (apiKey !== process.env.API_KEY) {
      console.log("Invalid API Key");
      return NextResponse.json({ message: "Invalid API Key" }, { status: 401 });
    }
    if (!userId || !pushToken)
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });
    console.log("Updating push token for user:", userId);
    const result = await updateUserPushToken(userId, pushToken);
    if (result.success) {
      console.log("Push token updated successfully");
      return NextResponse.json({ message: "Push token updated successfully" });
    } else {
      throw new Error("Failed to update push token");
    }
  } catch (error) {
    console.error("Error in updatePushToken:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error updating push token" }, { status: 500 });
  }
}
